Learn R Programming

ttestshiny (version 0.1.0)

runttestshiny: Launch ttestshiny Interface

Description

ttestshiny() loads interactive user interface built using R shiny.

Usage

runttestshiny()

Arguments

Value

Nothing

Details

Start ttestshiny

The interactive user interface is to provide an easy way for people who are learning ttest. Includes example data for testing out a few example analysis.

Examples

Run this code
# NOT RUN {
library(shiny)
ttestshiny()
# }

Run the code above in your browser using DataLab