ttestshiny() loads interactive user interface built using R shiny.
Usage
runttestshiny()
Arguments
Value
Nothing
Details
Start ttestshiny
The interactive user interface is to provide an easy way for people who are learning ttest. Includes example data for testing out a few example analysis.